@@ -5,7 +5,7 @@ from PythonPals import questions
 import pygame
 import pygame.gfxdraw
 import textwrap
-from PythonPals import player
+from PythonPals.player import Player, Coffee, Ruby, Eye
 
 class Screen():
     def __init__(self, width, height):
